Converts the old-style config file to the new multiple config files
upgrade_config.RdA function to upgrade from the singular old style config file to the new multi-file config files. The new config files enables the use functions such as pipeline_init(), pipeline_run() and pipeline_import_for().